@@ -169,6 +169,10 @@ def get_display_info() -> List[dict]:
                         count += 1
         except Exception:
             pass
+
+        # return info only which has correct data
+        info = [i for i in info if isinstance(i, dict)]
+
         __cache__.store('windows_monitors_info_raw', info)
 
     return info
@@ -313,14 +317,6 @@ class VCP:
 
         Raises:
             ctypes.WinError: upon failure to enumerate through the monitors
-
-        Example:
-            ```python
-            import screen_brightness_control as sbc
-
-            for monitor in sbc.windows.VCP.iter_physical_monitors():
-                print(sbc.windows.VCP.get_monitor_caps(monitor))
-            ```
         '''
         def callback(hmonitor, *_):
             monitors.append(HMONITOR(hmonitor))
